==> plasma-workspace-4.97.0.tar.xz: plasma-workspace-4.97.0/phonon/platform_kde/kdeplatformplugin.h <==
/*  This file is part of the KDE project
    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef PHONON_KDEPLATFORMPLUGIN_H
#define PHONON_KDEPLATFORMPLUGIN_H

#include <phonon/platformplugin.h>
#include <phonon/objectdescription.h>
#include <QtCore/QObject>
#include <kservice.h>

namespace Phonon {

class DeviceListing;

class KdePlatformPlugin : public QObject, public PlatformPlugin
{
    Q_PLUGIN_METADATA(IID "3PlatformPlugin.phonon.kde.org" FILE "phononbackend.json")
    Q_INTERFACES(Phonon::PlatformPlugin)
    Q_OBJECT
public:
    KdePlatformPlugin();
    ~KdePlatformPlugin();

    AbstractMediaStream *createMediaStream(const QUrl &url, QObject *parent);

    QIcon icon(const QString &name) const;
    void notification(const char *notificationName, const QString &text,
                      const QStringList &actions, QObject *receiver,
                      const char *actionSlot) const;
    QString applicationName() const;
    QObject *createBackend();
    QObject *createBackend(const QString &library, const QString &version);
    bool isMimeTypeAvailable(const QString &mimeType) const;
    void saveVolume(const QString &outputName, qreal volume);
    qreal loadVolume(const QString &outputName) const;

    virtual QList<int> objectDescriptionIndexes(ObjectDescriptionType type) const;
    virtual QHash<QByteArray, QVariant> objectDescriptionProperties(ObjectDescriptionType type, int index) const;

signals:
    void objectDescriptionChanged(ObjectDescriptionType);
};

} // namespace Phonon

#endif // PHONON_KDEPLATFORMPLUGIN_H

==> plasma-workspace_5.12.9.orig.tar.xz: plasma-workspace-5.12.9/phonon/platform_kde/kdeplatformplugin.h <==
/*  This file is part of the KDE project
    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef PHONON_KDEPLATFORMPLUGIN_H
#define PHONON_KDEPLATFORMPLUGIN_H

#include <phonon/platformplugin.h>
#include <phonon/objectdescription.h>
#include <QtCore/QObject>
#include <kservice.h>

namespace Phonon {

class DeviceListing;

class KdePlatformPlugin : public QObject, public PlatformPlugin
{
    Q_PLUGIN_METADATA(IID "3PlatformPlugin.phonon.kde.org" FILE "phononbackend.json")
    Q_INTERFACES(Phonon::PlatformPlugin)
    Q_OBJECT
public:
    KdePlatformPlugin();
    ~KdePlatformPlugin() override;

    AbstractMediaStream *createMediaStream(const QUrl &url, QObject *parent) override;

    QIcon icon(const QString &name) const override;
    void notification(const char *notificationName, const QString &text,
                      const QStringList &actions, QObject *receiver,
                      const char *actionSlot) const override;
    QString applicationName() const override;
    QObject *createBackend() override;
    QObject *createBackend(const QString &library, const QString &version) override;
    bool isMimeTypeAvailable(const QString &mimeType) const override;
    void saveVolume(const QString &outputName, qreal volume) override;
    qreal loadVolume(const QString &outputName) const override;

    QList<int> objectDescriptionIndexes(ObjectDescriptionType type) const override;
    QHash<QByteArray, QVariant> objectDescriptionProperties(ObjectDescriptionType type, int index) const override;

signals:
    void objectDescriptionChanged(ObjectDescriptionType);
};

} // namespace Phonon

#endif // PHONON_KDEPLATFORMPLUGIN_H
